[xiph-commits] r3803 - liboggz/trunk/src/tools

conrad at svn.annodex.net conrad at svn.annodex.net
Thu Nov 20 19:16:40 PST 2008


Author: conrad
Date: 2008-11-20 19:16:40 -0800 (Thu, 20 Nov 2008)
New Revision: 3803

Modified:
   liboggz/trunk/src/tools/oggz-merge.c
Log:
rename careful_for_theora to careful_for_video


Modified: liboggz/trunk/src/tools/oggz-merge.c
===================================================================
--- liboggz/trunk/src/tools/oggz-merge.c	2008-11-21 03:09:50 UTC (rev 3802)
+++ liboggz/trunk/src/tools/oggz-merge.c	2008-11-21 03:16:40 UTC (rev 3803)
@@ -196,8 +196,8 @@
   const ogg_page * og;
   int active;
 
-  /* For theora+vorbis, ensure theora bos is first */
-  int careful_for_theora = 0;
+  /* For theora+vorbis, or dirac+vorbis, ensure video bos is first */
+  int careful_for_video = 0;
 
   /* If all input files are Ogg Vorbis I, warn that the output will not be
    * a valid Ogg Vorbis I file as it will be multitrack. This is in response
@@ -206,7 +206,7 @@
   int v, warn_all_vorbis = 1;
 
   if (oggz_table_size (omdata->inputs) == 2)
-    careful_for_theora = 1;
+    careful_for_video = 1;
 
   while ((ninputs = oggz_table_size (omdata->inputs)) > 0) {
     min_units = -1;
@@ -239,7 +239,7 @@
               is_vorbis = (oggz_stream_get_content (input->reader, serialno) == OGGZ_CONTENT_VORBIS);
 
 	      if (i == 0 && is_vorbis)
-		careful_for_theora = 0;
+		careful_for_video = 0;
 	      else
 		active = 0;
 



More information about the commits mailing list